===================
Django Users Blue
===================

Users Collections is a Django app to manage users by author.

Quick start
==============

1. Add "blue_users" to your INSTALLED_APPS settings like this::

    INSTALLED_APPS = [
        ...
        'blue_users',
    ]

2. Starts.